@@ -59,6 +59,23 @@ const gchar*       tracker_ontologies_get_uri_by_id        (gint              id
 void               tracker_ontologies_add_id_uri_pair      (gint              id,
                                                             const gchar      *uri);
 
+void               tracker_ontologies_write_gvdb           (const gchar      *filename,
+                                                            GError          **error);
+void               tracker_ontologies_load_gvdb            (const gchar      *filename,
+                                                            GError          **error);
+GVariant *         tracker_ontologies_get_namespace_value_gvdb  (const gchar      *uri,
+                                                                 const gchar      *predicate);
+const gchar *      tracker_ontologies_get_namespace_string_gvdb (const gchar      *uri,
+                                                                 const gchar      *predicate);
+GVariant *         tracker_ontologies_get_class_value_gvdb      (const gchar      *uri,
+                                                                 const gchar      *predicate);
+const gchar *      tracker_ontologies_get_class_string_gvdb     (const gchar      *uri,
+                                                                 const gchar      *predicate);
+GVariant *         tracker_ontologies_get_property_value_gvdb   (const gchar      *uri,
+                                                                 const gchar      *predicate);
+const gchar *      tracker_ontologies_get_property_string_gvdb  (const gchar      *uri,
+                                                                 const gchar      *predicate);
+
 G_END_DECLS
 
 #endif /* __LIBTRACKER_DATA_ONTOLOGY_H__ */
