@@ -31,9 +31,9 @@
 
 #include "tracker-miner-object.h"
 
-G_BEGIN_DECLS
+#include "tracker-miner-common.h"
 
-#define TRACKER_MINER_FS_GRAPH_URN "urn:uuid:472ed0cc-40ff-4e37-9c0c-062d78656540"
+G_BEGIN_DECLS
 
 #define TRACKER_TYPE_MINER_FS         (tracker_miner_fs_get_type())
 #define TRACKER_MINER_FS(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), TRACKER_TYPE_MINER_FS, TrackerMinerFS))
@@ -48,8 +48,7 @@ typedef struct _TrackerMinerFSPrivate TrackerMinerFSPrivate;
 /**
  * TrackerMinerFS:
  *
- * Abstract miner abstract implementation to get data
- * from the filesystem.
+ * Abstract miner implementation to get data from the filesystem.
  **/
 struct _TrackerMinerFS {
 	TrackerMiner parent;
@@ -59,17 +58,26 @@ struct _TrackerMinerFS {
 /**
  * TrackerMinerFSClass:
  * @parent: parent object class
- * @check_file: Called when a file should be checked for further processing
- * @check_directory: Called when a directory should be checked for further processing
- * @check_directory_contents: Called when a directory should be checked for further processing, based on the directory contents.
- * @process_file: Called when the metadata associated to a file is requested.
- * @ignore_next_update_file: Called after a writeback event happens on a file.
- * @monitor_directory: Called to check whether a directory should be modified.
+ * @check_file: Called when a file should be checked for further
+ * processing.
+ * @check_directory: Called when a directory should be checked for
+ * further processing.
+ * @check_directory_contents: Called when a directory should be
+ * checked for further processing, based on the directory contents. 
+ * @process_file: Called when the metadata associated to a file is
+ * requested.
+ * @ignore_next_update_file: Called after a writeback event happens on
+ * a file.
+ * @monitor_directory: Called to check whether a directory should be
+ * modified.
  * @finished: Called when all processing has been performed.
+ * @process_file_attributes: Called when the metadata associated with
+ * a file's attributes changes, for example, the mtime.
  *
- * Prototype for the abstract class, @check_file, @check_directory, @check_directory_contents,
- * @process_file and @monitor_directory must be implemented in the deriving class in order to
- * actually extract data.
+ * Prototype for the abstract class, @check_file, @check_directory,
+ * @check_directory_contents, @process_file and @monitor_directory
+ * must be implemented in the deriving class in order to actually
+ * extract data.
  **/
 typedef struct {
 	TrackerMinerClass parent;
